@@ -1,5 +1,6 @@
 import argparse
 import logging
+import os
 from dataclasses import asdict
 from .model import AlgoSite
 
@@ -14,12 +15,16 @@ def get_parser():
 
 
 if __name__ == '__main__':
+  os.environ["WDM_LOG_LEVEL"] = str(logging.WARNING)
   ag = get_parser()
   logging.basicConfig(
       format='%(asctime)s %(levelname)-6s [%(filename)s:%(lineno)d] %(message)s',
       datefmt='%H%M%S',
   )
   logging.getLogger().setLevel(ag.log_level)
+  logger = logging.getLogger('selenium.webdriver.remote.remote_connection')
+  logger.setLevel(logging.WARNING)  # or any variant from ERROR, CRITICAL or NOTSET
+
   assert ag.problem_id or ag.user_id
   algosite = AlgoSite.get_site_by_prefix(ag.site_prefix)
   if ag.problem_id:
